package VMOMI::DVPortStatusVmDirectPathGen2InactiveReasonNetwork;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
